#!/usr/bin/env node
import { spawn } from 'child_process';
import { Command } from 'commander';
import { formatWithCollapse } from '../lib/collapsor.js';
import { applyFilter } from '../lib/filter.js';
import { exportLines } from '../lib/exporter.js';

const program = new Command();
program
  .argument('<cmd...>', 'Comando a ejecutar (por ejemplo "npm run dev")')
  .option('--filter <word>', 'Filtra líneas que contengan la palabra')
  .option('--export <file>', 'Exporta la salida filtrada a un archivo')
  .parse();

const options = program.opts();
const args = program.args;

// Desactiva colores en la salida del comando
const child = spawn(args.join(' '), {
  shell:   true,
  env:     { ...process.env, FORCE_COLOR: '0', NO_COLOR: '1' }
});

function processOutput(data) {
  let lines = data.toString().split('\n');
  if (options.filter) lines = applyFilter(lines, options.filter);
  const formatted = formatWithCollapse(lines, options);
  formatted.forEach(line => console.log(line));
  if (options.export) exportLines(formatted, options.export);
}

child.stdout.on('data', processOutput);
child.stderr.on('data', processOutput);