import stripAnsi from 'strip-ansi';
import chalk     from 'chalk';
import { highlightLine } from './formatter.js';

export function formatWithCollapse(lines, options = {}) {
  let stackBuffer = [];
  let inStack     = false;
  const output    = [];

  for (let raw of lines) {
    const line = stripAnsi(raw);
    if (options.filter && !line.toLowerCase().includes(options.filter.toLowerCase())) {
      continue;
    }

    if (/^\s*at\s/.test(line)) {
      stackBuffer.push(line);
      inStack = true;
    } else {
      if (inStack) {
        if (stackBuffer.length > 3) {
          output.push(chalk.gray(`📦 Stack trace de ${stackBuffer.length} líneas colapsado`));
        } else {
          output.push(...stackBuffer.map(l => chalk.dim(l)));
        }
        stackBuffer = [];
        inStack     = false;
      }
      output.push(highlightLine(line));
    }
  }

  // Al final, vuelca buffer si queda
  if (stackBuffer.length) {
    if (stackBuffer.length > 3) {
      output.push(chalk.gray(`📦 Stack trace de ${stackBuffer.length} líneas colapsado`));
    } else {
      output.push(...stackBuffer.map(l => chalk.dim(l)));
    }
  }

  return output;
}