import chalk from 'chalk';
import stripAnsi from 'strip-ansi';
import { regexes } from './regex.js';

// Función principal que detecta niveles y delega al formateo fino
export function highlightLine(rawLine) {
  // 1) Limpiar cualquier ANSI residual
  const line = stripAnsi(rawLine);

  // 2) Distinguir niveles principales
  if (/^\s*at\s/.test(line))                            return chalk.dim(line);
  if (/Caused by:/i.test(line))                         return chalk.redBright.bold('💥 ' + line);
  if (/ECONNREFUSED|ECONNRESET|ENOTFOUND/i.test(line))  return chalk.red.bold('🚫 ' + line);
  if (/GET|POST|PUT|DELETE/i.test(line))                return chalk.magentaBright('➡️  ' + line);
  if (/\b(404|500|503|403)\b/.test(line))               return chalk.bgRed.white.bold('🔻 ' + line);
  if (/ERROR|Exception|fail/i.test(line))               return chalk.red.bold('❌ ' + line);
  if (/WARN/i.test(line))                               return chalk.yellow('⚠️ ' + line);
  if (/INFO/i.test(line))                               return chalk.blue('ℹ️ ' + line);
  if (/DEBUG/i.test(line))                              return chalk.gray('🐞 ' + line);
  if (/✔|✓/.test(line))                                 return chalk.green('✅ ' + line);
  if (/✖|×/.test(line))                                 return chalk.red('✖️ ' + line);

  // 3) Si no encaja, entra al formateo fino
  return formatLine(line);
}

// Formateo fino: strings, JSON, URLs, símbolos, tiempos, etc.
export function formatLine(line) {
  // Framework names destacados
  line = line.replace(regexes.frameworks, m => chalk.magentaBright.bold(m));

  // Strings entre comillas
  line = line.replace(regexes.doubleQuotedString,  (_, s) => chalk.green(`"${s}"`));
  line = line.replace(regexes.singleQuotedString,  (_, s) => chalk.green(`'${s}'`));

  // Booleans, null y undefined
  line = line.replace(/\b(true|false)\b/g,  m => chalk.blueBright(m));
  line = line.replace(/\bnull\b/g,           m => chalk.gray(m));
  line = line.replace(/\bundefined\b/g,      m => chalk.gray(m));

  // URLs y puertos locales
  line = line.replace(regexes.url,           m => chalk.cyan.underline(m));
  line = line.replace(regexes.localhost,     m => chalk.cyanBright(m));

  // Tiempos en ms
  line = line.replace(/\b\d+ms\b/g,          m => chalk.yellow(m));

  // Símbolos de JSON y código
  line = line.replace(/([{}\[\]():,])/g,     m => chalk.gray(m));

  return line;
}